@@ -1,10 +1,8 @@
 package Test::DBIx::Class::Schema;
-{
-  $Test::DBIx::Class::Schema::VERSION = '1.0.6';
-}
 {
   $Test::DBIx::Class::Schema::DIST = 'Test-DBIx-Class-Schema';
 }
+$Test::DBIx::Class::Schema::VERSION = '1.0.7';
 # vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
 use warnings;
@@ -52,7 +50,7 @@ sub run_tests {
     # create a new resultset object and perform tests on it
     # - this allows us to test ->my_column() without requiring data
     $rs = $schema->resultset( $self->{moniker} );
-    $record = $schema->resultset( $self->{moniker} )->new({});
+    $record = $schema->resultset( $self->{moniker} )->new_result({});
 
     # make sure our record presents itself as the correct object type
     if (defined $self->{glue}) {
@@ -294,13 +292,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::DBIx::Class::Schema - DBIx::Class schema sanity checking tests
 
 =head1 VERSION
 
-version 1.0.6
+version 1.0.7
 
 =head1 SYNOPSIS
 
@@ -430,7 +430,7 @@ Chisel Wright <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Chisel Wright.
+This software is copyright (c) 2015 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
